@@ -83,7 +83,8 @@ def common_options(parser, opts):
     group = parser.add_argument_group("Server Replay")
     opts.make_parser(group, "server_replay", metavar="PATH", short="S")
     opts.make_parser(group, "server_replay_kill_extra")
-    opts.make_parser(group, "server_replay_nopop")
+    opts.make_parser(group, "server_replay_extra")
+    opts.make_parser(group, "server_replay_reuse")
     opts.make_parser(group, "server_replay_refresh")
 
     # Map Remote
